searchData={"items":[{"type":"module","title":"Geolixir","doc":"Geolixir provides a simple and unified interface for geocoding and reverse\ngeocoding using various external providers.\n\nIt allows converting addresses to geographical coordinates (latitude and longitude)\nand vice-versa.","ref":"Geolixir.html"},{"type":"module","title":"Usage - Geolixir","doc":"Add Geolixir to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [\n    {:geolixir, \"~> 0.1.3\"}\n  ]\nend\n```\n\nThen fetch the dependencies:\n\n```bash\nmix deps.get\n```","ref":"Geolixir.html#module-usage"},{"type":"module","title":"Geocoding - Geolixir","doc":"```elixir\n# Using the default provider (OpenStreetMap)\niex> Geolixir.geocode(\"1600 Amphitheatre Parkway, Mountain View, CA\")\n{:ok, %Geolixir.Result{\n  coordinates: %Geolixir.Coords{lat: 37.4224764, lon: -122.0842499},\n  location: %Geolixir.Location{...},\n  ...\n}}\n\n# Using a specific provider (e.g., Geoapify, requires API key)\niex> Geolixir.geocode(\"Eiffel Tower, Paris\", provider: :geoapify, api_key: \"YOUR_GEOAPIFY_KEY\")\n{:ok, %Geolixir.Result{...}}\n```","ref":"Geolixir.html#module-geocoding"},{"type":"module","title":"Reverse Geocoding - Geolixir","doc":"```elixir\n# Using the default provider\niex> Geolixir.reverse_geocode(48.8584, 2.2945)\n{:ok, %Geolixir.Result{\n  location: %Geolixir.Location{formatted_address: \"Tour Eiffel, 5, Avenue Anatole France, ...\", ...},\n  ...\n}}\n\n# Using a specific provider (e.g., PositionStack, requires API key)\niex> Geolixir.reverse_geocode(40.7128, -74.0060, provider: :position_stack, api_key: \"YOUR_POSITIONSTACK_KEY\")\n{:ok, %Geolixir.Result{...}}\n```\n\nSee `geocode/2` and `reverse_geocode/3` for more details and options.","ref":"Geolixir.html#module-reverse-geocoding"},{"type":"function","title":"Geolixir.geocode/2","doc":"Geocodes a given address string into geographical coordinates.\n\nIt uses the configured default provider unless a specific `:provider` is\nspecified in the options. Some providers may require an `:api_key`.","ref":"Geolixir.html#geocode/2"},{"type":"function","title":"Parameters - Geolixir.geocode/2","doc":"- `address`: The address string to geocode (e.g., \"1600 Amphitheatre Parkway, Mountain View, CA\").\n  - `opts`: A keyword list of options.\n    - `:provider`: (Optional) The atom representing the provider module to use (e.g., `:geoapify`, `:open_street_maps`). Defaults to `:open_street_maps`.\n    - `:api_key`: (Optional) The API key required by some providers.\n    - Other options specific to the chosen provider may also be passed.","ref":"Geolixir.html#geocode/2-parameters"},{"type":"function","title":"Returns - Geolixir.geocode/2","doc":"- `{:ok, %Result{}}`: On success, returns a tuple with `:ok` and a `Geolixir.Result` struct containing coordinates, location details, bounds, and metadata.\n  - `{:error, reason}`: On failure, returns a tuple with `:error` and the reason (e.g., `:no_results_found`, `:invalid_api_key`, HTTP error details).","ref":"Geolixir.html#geocode/2-returns"},{"type":"function","title":"Examples - Geolixir.geocode/2","doc":"iex> Geolixir.geocode(\"Eiffel Tower, Paris\")\n    {:ok, %Geolixir.Result{coordinates: %Geolixir.Coords{lat: 48.858..., lon: 2.294...}, ...}}\n\n    iex> Geolixir.geocode(\"NonExistentPlace12345\", provider: :open_street_maps)\n    {:error, :no_results_found} # Example error, actual error may vary\n\n    iex> Geolixir.geocode(\"Statue of Liberty\", provider: :geoapify, api_key: \"YOUR_KEY\")\n    {:ok, %Geolixir.Result{...}} # Requires a valid Geoapify key\n\n    iex> Geolixir.geocode(\"Some Address\", provider: :unknown_provider)\n    ** (ArgumentError) Unknown provider: unknown_provider. Available providers: [...]","ref":"Geolixir.html#geocode/2-examples"},{"type":"function","title":"Geolixir.reverse_geocode/3","doc":"Reverse geocodes geographical coordinates (latitude and longitude) into an address.\n\nIt uses the configured default provider unless a specific `:provider` is\nspecified in the options. Some providers may require an `:api_key`.","ref":"Geolixir.html#reverse_geocode/3"},{"type":"function","title":"Parameters - Geolixir.reverse_geocode/3","doc":"- `lat`: The latitude.\n  - `lon`: The longitude.\n  - `opts`: A keyword list of options.\n    - `:provider`: (Optional) The atom representing the provider module to use (e.g., `:geoapify`, `:open_street_maps`). Defaults to `:open_street_maps`.\n    - `:api_key`: (Optional) The API key required by some providers.\n    - Other options specific to the chosen provider may also be passed.","ref":"Geolixir.html#reverse_geocode/3-parameters"},{"type":"function","title":"Returns - Geolixir.reverse_geocode/3","doc":"- `{:ok, %Result{}}`: On success, returns a tuple with `:ok` and a `Geolixir.Result` struct containing location details, coordinates, bounds, and metadata.\n  - `{:error, reason}`: On failure, returns a tuple with `:error` and the reason (e.g., `:no_results_found`, `:invalid_coordinates`, HTTP error details).","ref":"Geolixir.html#reverse_geocode/3-returns"},{"type":"function","title":"Examples - Geolixir.reverse_geocode/3","doc":"iex> Geolixir.reverse_geocode(40.7128, -74.0060) # New York City Hall approx.\n    {:ok, %Geolixir.Result{location: %Geolixir.Location{formatted_address: \"City Hall Park, ...\", ...}, ...}}\n\n    iex> Geolixir.reverse_geocode(999.0, 999.0)\n    {:error, :invalid_coordinates} # Example error, actual error may vary\n\n    iex> Geolixir.reverse_geocode(51.5074, -0.1278, provider: :position_stack, api_key: \"YOUR_KEY\")\n    {:ok, %Geolixir.Result{...}} # Requires a valid PositionStack key","ref":"Geolixir.html#reverse_geocode/3-examples"},{"type":"module","title":"Geolixir.Providers.Base","doc":"Base module for geocoding providers with common functionality.","ref":"Geolixir.Providers.Base.html"},{"type":"module","title":"Geolixir.Providers.Geoapify","doc":"Geoapify geocoding provider.\nDoes REQUIRES a key.","ref":"Geolixir.Providers.Geoapify.html"},{"type":"function","title":"Geolixir.Providers.Geoapify.geocode_list/2","doc":"","ref":"Geolixir.Providers.Geoapify.html#geocode_list/2"},{"type":"function","title":"Geolixir.Providers.Geoapify.reverse_geocode_list/2","doc":"","ref":"Geolixir.Providers.Geoapify.html#reverse_geocode_list/2"},{"type":"module","title":"Geolixir.Providers.Geocoding","doc":"GeoCoding geocoding provider.\nDoes REQUIRES a key.","ref":"Geolixir.Providers.Geocoding.html"},{"type":"function","title":"Geolixir.Providers.Geocoding.geocode_list/2","doc":"","ref":"Geolixir.Providers.Geocoding.html#geocode_list/2"},{"type":"function","title":"Geolixir.Providers.Geocoding.reverse_geocode_list/2","doc":"","ref":"Geolixir.Providers.Geocoding.html#reverse_geocode_list/2"},{"type":"module","title":"Geolixir.Providers.OpenStreetMap","doc":"Geolixir provider for the OpenStreetMap Nominatim API.\n\nThis provider uses the public Nominatim service (`https://nominatim.openstreetmap.org`).","ref":"Geolixir.Providers.OpenStreetMap.html"},{"type":"module","title":"Features - Geolixir.Providers.OpenStreetMap","doc":"- Geocoding (address to coordinates)\n- Reverse Geocoding (coordinates to address)","ref":"Geolixir.Providers.OpenStreetMap.html#module-features"},{"type":"module","title":"Configuration - Geolixir.Providers.OpenStreetMap","doc":"- **API Key:** Not required for the public Nominatim API.\n- **Endpoint:** `https://nominatim.openstreetmap.org` (configurable via Base, but usually not needed)","ref":"Geolixir.Providers.OpenStreetMap.html#module-configuration"},{"type":"module","title":"Usage Notes - Geolixir.Providers.OpenStreetMap","doc":"- Be mindful of the [Nominatim Usage Policy](https://operations.osmfoundation.org/policies/nominatim/), especially regarding rate limits and acceptable use for the public API. For heavy usage, consider hosting your own instance.\n- Default language for results is English (`\"accept-language\": \"en\"`).\n- Address details are requested by default (`addressdetails: 1`).","ref":"Geolixir.Providers.OpenStreetMap.html#module-usage-notes"},{"type":"function","title":"Geolixir.Providers.OpenStreetMap.geocode_list/2","doc":"","ref":"Geolixir.Providers.OpenStreetMap.html#geocode_list/2"},{"type":"function","title":"Geolixir.Providers.OpenStreetMap.reverse_geocode_list/2","doc":"","ref":"Geolixir.Providers.OpenStreetMap.html#reverse_geocode_list/2"},{"type":"module","title":"Geolixir.Providers.PositionStack","doc":"PositionStack geocoding provider.\nDoes REQUIRES a key.","ref":"Geolixir.Providers.PositionStack.html"},{"type":"function","title":"Geolixir.Providers.PositionStack.geocode_list/2","doc":"","ref":"Geolixir.Providers.PositionStack.html#geocode_list/2"},{"type":"function","title":"Geolixir.Providers.PositionStack.reverse_geocode_list/2","doc":"","ref":"Geolixir.Providers.PositionStack.html#reverse_geocode_list/2"},{"type":"module","title":"Geolixir.Bounds","doc":"Represents geographical boundaries with northeast and southwest coordinates.","ref":"Geolixir.Bounds.html"},{"type":"type","title":"Geolixir.Bounds.t/0","doc":"","ref":"Geolixir.Bounds.html#t:t/0"},{"type":"module","title":"Geolixir.Coords","doc":"Represents geographic coordinates (latitude and longitude) with associated metadata.","ref":"Geolixir.Coords.html"},{"type":"type","title":"Geolixir.Coords.t/0","doc":"Geographic coordinates with associated metadata","ref":"Geolixir.Coords.html#t:t/0"},{"type":"module","title":"Geolixir.Location","doc":"Represents a geographical location with address components.","ref":"Geolixir.Location.html"},{"type":"type","title":"Geolixir.Location.t/0","doc":"","ref":"Geolixir.Location.html#t:t/0"},{"type":"module","title":"Geolixir.Result","doc":"Represents a standardized result from a geocoding or reverse geocoding operation.\n\nThis struct consolidates information parsed from various provider responses into\na consistent format.","ref":"Geolixir.Result.html"},{"type":"type","title":"Geolixir.Result.t/0","doc":"The struct holding standardized geolocation results.\n- `:coordinates`: A `Geolixir.Coords` struct with latitude and longitude.\n- `:bounds`: A `Geolixir.Bounds` struct representing the bounding box, if available.\n- `:location`: A `Geolixir.Location` struct containing address components.\n- `:metadata`: The original, raw response map from the provider for debugging or accessing provider-specific fields.","ref":"Geolixir.Result.html#t:t/0"},{"type":"module","title":"Geolixir.HttpClient","doc":"A simple HTTP client wrapper around HTTPoison, tailored for Geolixir providers.\n\nThis module handles making HTTP requests, processing responses (including basic\nJSON decoding), and normalizing success/error tuples. It is used internally\nby the various geocoding providers.","ref":"Geolixir.HttpClient.html"},{"type":"type","title":"Geolixir.HttpClient.error_response/0","doc":"Represents an error response map after processing.\n- `:status_code`: The HTTP status code (integer).\n- `:body`: The response body, decoded as JSON if possible, otherwise the raw string.\n- `:headers`: A list of response header tuples.","ref":"Geolixir.HttpClient.html#t:error_response/0"},{"type":"type","title":"Geolixir.HttpClient.http_options/0","doc":"Represents options passed to the underlying HTTP client (HTTPoison).\nSee `HTTPoison.request/5` options for details.","ref":"Geolixir.HttpClient.html#t:http_options/0"},{"type":"function","title":"Geolixir.HttpClient.request/2","doc":"Makes an HTTP request using HTTPoison.\n\nIt automatically decodes JSON responses and wraps the result in standardized\n`{:ok, response_map}` or `{:error, error_map | HTTPoison.Error.t()}` tuples.","ref":"Geolixir.HttpClient.html#request/2"},{"type":"function","title":"Parameters - Geolixir.HttpClient.request/2","doc":"- `request_config`: A `t:request_config/0` map containing `:method`, `:url`,\n    and optional `:query_params` and `:headers`.\n  - `config`: (Optional) A keyword list for additional configuration.\n    - `:http_options`: A `t:http_options/0` keyword list passed directly to `HTTPoison.request/5`.","ref":"Geolixir.HttpClient.html#request/2-parameters"},{"type":"function","title":"Returns - Geolixir.HttpClient.request/2","doc":"- `{:ok, success_response()}`: For successful HTTP requests (status 2xx).\n  - `{:error, error_response()}`: For HTTP requests with error status codes (non-2xx).\n  - `{:error, %HTTPoison.Error{}}`: If the HTTP request itself fails (e.g., connection error).","ref":"Geolixir.HttpClient.html#request/2-returns"},{"type":"type","title":"Geolixir.HttpClient.request_config/0","doc":"Represents the configuration for an HTTP request.\n- `:method`: The HTTP method (e.g., `:get`, `:post`).\n- `:url`: The target URL string.\n- `:query_params`: (Optional) A map of query parameters. Defaults to `%{}%`.\n- `:headers`: (Optional) A list of HTTP header tuples. Defaults to `[]`.","ref":"Geolixir.HttpClient.html#t:request_config/0"},{"type":"type","title":"Geolixir.HttpClient.success_response/0","doc":"Represents a successful response map after processing.\n- `:status_code`: The HTTP status code (integer).\n- `:body`: The response body, decoded as JSON if possible, otherwise the raw string.\n- `:headers`: A list of response header tuples.","ref":"Geolixir.HttpClient.html#t:success_response/0"},{"type":"behaviour","title":"Geolixir.Provider","doc":"Defines the behavior for all Geolixir geocoding providers.\n\nEach provider module must implement the required callbacks defined here.\nThis ensures a consistent interface across different geocoding services.\n\nProviders typically handle:\n- Constructing the correct API request URL and parameters.\n- Making the HTTP request via `Geolixir.HttpClient`.\n- Parsing the response from the specific provider's format.\n- Transforming the parsed data into the standardized `Geolixir.Result` struct.\n- Handling provider-specific errors and API key requirements.","ref":"Geolixir.Provider.html"},{"type":"callback","title":"Geolixir.Provider.geocode/2","doc":"Callback for geocoding a single address.","ref":"Geolixir.Provider.html#c:geocode/2"},{"type":"callback","title":"Parameters - Geolixir.Provider.geocode/2","doc":"- `payload`: A map containing the data needed for geocoding (e.g., `%{address: \"...\"}`).\n  - `opts`: A keyword list of options, potentially including `:api_key` and provider-specific settings.","ref":"Geolixir.Provider.html#c:geocode/2-parameters"},{"type":"callback","title":"Return Values - Geolixir.Provider.geocode/2","doc":"- `{:ok, Result.t()}`: On success.\n  - `{:error, reason}`: On failure.","ref":"Geolixir.Provider.html#c:geocode/2-return-values"},{"type":"callback","title":"Geolixir.Provider.geocode_list/2","doc":"Callback for geocoding a list of addresses (batch operation). Optional.","ref":"Geolixir.Provider.html#c:geocode_list/2"},{"type":"callback","title":"Parameters - Geolixir.Provider.geocode_list/2","doc":"- `payload`: A map containing the data needed for batch geocoding (e.g., `%{addresses: [...]}`).\n  - `opts`: A keyword list of options.","ref":"Geolixir.Provider.html#c:geocode_list/2-parameters"},{"type":"callback","title":"Return Values - Geolixir.Provider.geocode_list/2","doc":"- `{:ok, list(Result.t())}`: On success.\n  - `{:error, reason}`: On failure.","ref":"Geolixir.Provider.html#c:geocode_list/2-return-values"},{"type":"callback","title":"Geolixir.Provider.reverse_geocode/2","doc":"Callback for reverse geocoding a single pair of coordinates.","ref":"Geolixir.Provider.html#c:reverse_geocode/2"},{"type":"callback","title":"Parameters - Geolixir.Provider.reverse_geocode/2","doc":"- `payload`: A map containing the data needed for reverse geocoding (e.g., `%{lat: ..., lon: ...}`).\n  - `opts`: A keyword list of options.","ref":"Geolixir.Provider.html#c:reverse_geocode/2-parameters"},{"type":"callback","title":"Return Values - Geolixir.Provider.reverse_geocode/2","doc":"- `{:ok, Result.t()}`: On success.\n  - `{:error, reason}`: On failure.","ref":"Geolixir.Provider.html#c:reverse_geocode/2-return-values"},{"type":"callback","title":"Geolixir.Provider.reverse_geocode_list/2","doc":"Callback for reverse geocoding a list of coordinates (batch operation). Optional.","ref":"Geolixir.Provider.html#c:reverse_geocode_list/2"},{"type":"callback","title":"Parameters - Geolixir.Provider.reverse_geocode_list/2","doc":"- `payload`: A map containing the data needed for batch reverse geocoding (e.g., `%{coordinates: [%{lat: ..., lon: ...}, ...]}`).\n  - `opts`: A keyword list of options.","ref":"Geolixir.Provider.html#c:reverse_geocode_list/2-parameters"},{"type":"callback","title":"Return Values - Geolixir.Provider.reverse_geocode_list/2","doc":"- `{:ok, list(Result.t())}`: On success.\n  - `{:error, reason}`: On failure.","ref":"Geolixir.Provider.html#c:reverse_geocode_list/2-return-values"},{"type":"extras","title":"Geolixir","doc":"# Geolixir\n\nWelcome to Geolixir! This library makes it simple to work with geocoding in your Elixir projects. Easily convert addresses to coordinates (geocoding) and coordinates back to addresses (reverse geocoding).","ref":"readme.html"},{"type":"extras","title":"✨ Features - Geolixir","doc":"*   **Geocoding:** Find latitude and longitude from an address.\n*   **Reverse Geocoding:** Find address details from latitude and longitude.\n*   **Multiple Providers:** Supports various geocoding services (like OpenStreetMap, Geoapify, etc.). You can choose your preferred provider or stick with the default.\n*   **Simple Interface:** Easy-to-use functions for common tasks.","ref":"readme.html#features"},{"type":"extras","title":"🚀 Installation - Geolixir","doc":"Add `geolixir` to your `mix.exs` dependencies:\n\n```elixir\ndef deps do\n  [\n    {:geolixir, \"~> 0.1.3\"}\n  ]\nend\n```\n\nThen, run `mix deps.get` in your terminal.","ref":"readme.html#installation"},{"type":"extras","title":"💡 Usage - Geolixir","doc":"Here's how you can use Geolixir:","ref":"readme.html#usage"},{"type":"extras","title":"Geocoding (Address to Coordinates) - Geolixir","doc":"```elixir\n# Using the default provider (OpenStreetMap)\niex> Geolixir.geocode(\"1600 Amphitheatre Parkway, Mountain View, CA\")\n{:ok, %Geolixir.Result{\n  coordinates: %Geolixir.Coords{lat: 37.4224764, lon: -122.0842499},\n  location: %Geolixir.Location{...},\n  bounds: %Geolixir.Bounds{...},\n  metadata: %{}\n}}\n\n# Using a specific provider (e.g., Geoapify, requires API key)\niex> Geolixir.geocode(\"Eiffel Tower, Paris\", provider: :geoapify, api_key: \"YOUR_GEOAPIFY_KEY\")\n{:ok, %Geolixir.Result{...}}","ref":"readme.html#geocoding-address-to-coordinates"},{"type":"extras","title":"Reverse Geocoding (Coordinates to Address) - Geolixir","doc":"```elixir\n# Using the default provider\niex> Geolixir.reverse_geocode(48.8584, 2.2945)\n{:ok, %Geolixir.Result{\n  location: %Geolixir.Location{formatted_address: \"Tour Eiffel, 5, Avenue Anatole France, ...\", ...},\n  ...\n}}\n\n# Using a specific provider (e.g., PositionStack, requires API key)\niex> Geolixir.reverse_geocode(40.7128, -74.0060, provider: :position_stack, api_key: \"YOUR_POSITIONSTACK_KEY\")\n{:ok, %Geolixir.Result{...}}\n\n# Handling errors\niex> Geolixir.reverse_geocode(999.0, 999.0)\n{:error, _provider_error_map} # Example error\n```\n\n**Note:** Some providers require an API key. Pass it using the `api_key: \"your_key\"` option. Check the specific provider module documentation for details.","ref":"readme.html#reverse-geocoding-coordinates-to-address"},{"type":"extras","title":"🛣️ Roadmap - Geolixir","doc":"*   Create documentation on HexDocs\n*   Implement batch operations (`list_geocode`, `list_reverse_geocode`).\n*   Add support for more geocoding providers.\n*   Enhance error handling.","ref":"readme.html#roadmap"},{"type":"extras","title":"📚 Documentation - Geolixir","doc":"Full documentation can be generated using ExDoc and published on [HexDocs](https://hexdocs.pm/geolixir).","ref":"readme.html#documentation"},{"type":"extras","title":"📝 License - Geolixir","doc":"Licensed under the [MIT License](./LICENSE).","ref":"readme.html#license"},{"type":"extras","title":"LICENSE","doc":"MIT License\n\nCopyright (c) 2025 Rogerio Bordignon\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the “Software”), to deal\nin the Software without restriction, including without limitation the rights  \nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell     \ncopies of the Software, and to permit persons to whom the Software is         \nfurnished to do so, subject to the following conditions:                      \n\nThe above copyright notice and this permission notice shall be included in    \nall copies or substantial portions of the Software.                           \n\nTHE SOFTWARE IS PROVIDED “AS IS”, WITHOUT WARRANTY OF ANY KIND, EXPRESS OR    \nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,      \nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE   \nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER       \nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN    \nTHE SOFTWARE.","ref":"license.html"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.37.3"}}